==> haskell-binary-instances-1.0.4-153.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.4
visibility:           public
id:                   binary-instances-1.0.4-LRyqc9c5oY9Dn07NM988NQ
key:                  binary-instances-1.0.4-LRyqc9c5oY9Dn07NM988NQ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  80027c1e217c7d8de617e28925bf2dcb
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.4-LRyqc9c5oY9Dn07NM988NQ
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-1VCGcurzJlr6bEl6Wn9GAU
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-binary-0.2.1.1-Gj3kZI8lApt9vSR18tt3q2
    time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    vector-binary-instances-0.2.5.2-LMaYNjTJVg9Be5d5O1SNoZ

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-instances-1.0.4-154-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.4
visibility:           public
id:                   binary-instances-1.0.4-21lVu4PKcafFMmP9h6qqCY
key:                  binary-instances-1.0.4-21lVu4PKcafFMmP9h6qqCY
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  221239673a2189af31bfaa274fd74429
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.4-21lVu4PKcafFMmP9h6qqCY
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-2QdNlgpLYWR3AHIOi4WILQ
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-binary-0.2.1.1-Gj3kZI8lApt9vSR18tt3q2
    time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    vector-binary-instances-0.2.5.2-DefExvwOSIi1i0IrJrD1MU

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
